@@ -72,9 +72,9 @@ class Domoticz(IPlugin):
  		log.msg("inten :  %s" % (inten)
 		if jsonInput['outcome']['entities']['location']['body'] :
 			location = jsonInput['outcome']['entities']['location']['body']
-#		else:
-#			bodies = "pas de lieu"
-#			location= "VIDE"
+		else:
+			bodies = "pas de lieu"
+			location= "VIDE"
 #		if jsonInput['outcome']['entities']['local_search_query']['value'] :
 #			local = jsonInput['outcome']['entities']['local_search_query']['value']
 #		else:
